# MILI <small>1.0.7</small>

Minimal immediate-mode python user interface library.

You can find MILI at its latest version on [<big>**PyPI**</big>](https://pypi.org/project/mili-ui/) and install it and import it using the following command and code:

```sh
pip install mili-ui
```

```py
import mili
```

You can check for changes in the library by visiting the [<big>**changelog**</big>](https://github.com/damusss/mili/blob/main/CHANGELOG.md).

# [<small>MILI Guide</small>](https://github.com/damusss/mili/blob/main/guide/guide.md)

After installing MILI you may also open the guide using the following command:

```sh
py -m mili guide
```

# [<small>MILI Demo</small>](https://github.com/damusss/mili/blob/main/mili/demo/demo.py) (incomplete)

NOTE: The demo is still incomplete. It will be completed by the next update.

A demo program exists to showcase what MILI can do. You can run it using one of the following commands:
```sh
mili-demo
```
```sh
py -m mili demo
```
